@@ -451,7 +451,8 @@ class Utils(object):
 					cloc_file_handle = open(cls.cloc_file, 'rb')
 					s3.Bucket('sken-scanner-output').put_object(Key=app_id + '/' + scan_id + '/sken-cloc.json', Body=cloc_file_handle)
 			except Exception as ce:
-				pass
+				# ignore
+				cls.noop()
 		
 			print('Output file uploaded')
 		except Exception as e:
@@ -465,7 +466,8 @@ class Utils(object):
 					os.remove(cls.cloc_file)
 					cls.cloc_file = None
 			except Exception as fe:
-				pass
+				# ignore
+				cls.noop()
 
 		return scan_id
 
@@ -488,3 +490,7 @@ class Utils(object):
 			count -= 1
 			time.sleep(1)
 
+	@classmethod
+	def noop(cls):
+		pass
+
